@@ -1,14 +1,17 @@
+from typing import Optional
+
 from .base import Item
 
 
 class File(Item):
+    """Represents a file within a deployment endpoint."""
 
     def __init__(
         self,
         *,
-        name,
-        path,
-        description=None
+        name: str,
+        path: str,
+        description: Optional[str] = None
     ) -> None:
         self.name = name
         self.path = path
