@@ -1,15 +1,18 @@
 from enum import Enum
+from typing import List, Optional, Union
 
 from .base import Item
 
 
 class KeepDirectories(Enum):
+    """How to retain directories when using storage wildcards."""
+
     NONE = 'none'
     SUFFIX = 'suffix'
     FULL = 'full'
 
     @classmethod
-    def cast(cls, value):
+    def cast(cls, value: Union[bool, str]) -> 'KeepDirectories':
         if not value:
             return KeepDirectories.NONE
         if value is True:
@@ -18,16 +21,17 @@ class KeepDirectories(Enum):
 
 
 class Input(Item):
+    """Represents an input definition within a step definition."""
 
     def __init__(
         self,
         *,
-        name,
-        default=None,
-        optional=False,
-        description=None,
-        keep_directories=False,
-        filename=None
+        name: str,
+        default: Optional[Union[List[str], str]] = None,
+        optional: bool = False,
+        description: Optional[str] = None,
+        keep_directories: bool = False,
+        filename: Optional[str] = None
     ) -> None:
         self.name = name
         self.default = default  # may be None, a string or a list of strings
