@@ -29,8 +29,4 @@ class ExecutionNode(Node):
         config = context['config']
         pipeline = context['pipeline']
         if self.step not in config.steps:
-            lint_result.add_error('Pipeline {pipeline} node {node} step {step} does not exist'.format(
-                pipeline=pipeline.name,
-                node=self.name,
-                step=self.step,
-            ))
+            lint_result.add_error(f'Pipeline {pipeline.name} node {self.name} step {self.step} does not exist')
