@@ -1,7 +1,9 @@
+from typing import Any, IO, Union
+
 from yaml import safe_load
 
 
-def read_yaml(yaml):
+def read_yaml(yaml: Union[dict, list, bytes, str, IO]) -> Any:
     if isinstance(yaml, (dict, list)):  # Smells already parsed
         return yaml
     if isinstance(yaml, bytes):
@@ -9,9 +11,9 @@ def read_yaml(yaml):
     return safe_load(yaml)  # can be a stream or a string
 
 
-def listify(value) -> list:
+def listify(value: Any) -> list:
     """
-    Wrap the given value into a list, with the below provisions:
+    Wrap the given value into a list, with provisions outlined below.
 
     * If the value is a list or a tuple, it's coerced into a new list.
     * If the value is None, an empty list is returned.
@@ -19,7 +21,6 @@ def listify(value) -> list:
 
     :param value: A value.
     :return: a list!
-    :rtype: list
     """
     if value is None:
         return []
